@@ -4,7 +4,7 @@ import subprocess
 
 from google.cloud import secretmanager
 
-from akerbp.mlops.utils import logger 
+from akerbp.mlops.core import logger 
 
 logging=logger.get_logger(name='gc_helper')
 
