@@ -6,8 +6,8 @@ Generic test for services (training or prediction)
 import os
 from importlib import import_module
 
-SERVICE_NAME = os.environ['SERVICE_NAME']
-service = import_module(f"akerbp.mlops.{SERVICE_NAME}.service").service
+service_name = os.environ['SERVICE_NAME']
+service = import_module(f"akerbp.mlops.{service_name}.service").service
 
 from service_settings import mlops_settings #generated during deployment
 
@@ -27,17 +27,17 @@ def mock_saver(api_key_files, path, metadata):
 def test_service():
    
    service_test = ServiceTest()
-   input = getattr(service_test, f"{SERVICE_NAME}_input")
-   check = getattr(service_test, f"{SERVICE_NAME}_check")
+   input = getattr(service_test, f"{service_name}_input")
+   check = getattr(service_test, f"{service_name}_check")
 
    
-   if SERVICE_NAME == 'training':
+   if service_name == 'training':
       response = service(data=input, secrets=api_keys, saver=mock_saver)
-   elif SERVICE_NAME == 'prediction':
+   elif service_name == 'prediction':
       response = service(data=input, secrets=api_keys)
    else:
       raise Exception("Unknown service name")
    
    assert response['status'] == 'ok'
-   assert check(response[SERVICE_NAME])
+   assert check(response[service_name])
    
\ No newline at end of file
