@@ -3,10 +3,13 @@ import warnings
 warnings.simplefilter("ignore")
 
 from akerbp.mlops.training.service import service
-from akerbp.mlops.utils import logger
+from akerbp.mlops.core import logger
+from akerbp.mlops import __version__ as version
 
 logging=logger.get_logger()
 
+logging.debug(f"MLOps framework version {version}")
+
 def handle(data, secrets):
    try:
       return service(data, secrets)
